<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// english.inc
//
// English language strings

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "No repository given";
$lang["NOPATH"] = "Path not found";
$lang["SUPPLYREP"] = "Please set up a repository path in include/config.inc using \$config->parentPath or \$config->addRepository<p>See the installation guide for more details";

$lang["DIFFREVS"] = "Diff between revs";
$lang["AND"] = "and";
$lang["REV"] = "Rev";
$lang["LINE"] = "Line";
$lang["SHOWENTIREFILE"] = "Show entire file";
$lang["SHOWCOMPACT"] = "Only display areas with differences";

$lang["DIFFPREV"] = "Compare with Previous";
$lang["BLAME"] = "Blame";

$lang["REVINFO"] = "Revision Information";
$lang["GOYOUNGEST"] = "Go to most recent revision";
$lang["LASTMOD"] = "Last modification";
$lang["LOGMSG"] = "Log message";
$lang["CHANGES"] = "Changes";
$lang["SHOWCHANGED"] = "Show changed files";
$lang["HIDECHANGED"] = "Hide changed files";
$lang["NEWFILES"] = "New Files";
$lang["CHANGEDFILES"] = "Modified files";
$lang["DELETEDFILES"] = "Deleted files";
$lang["VIEWLOG"] = "View&nbsp;Log";
$lang["PATH"] = "Path";
$lang["AUTHOR"] = "Author";
$lang["AGE"] = "Age";
$lang["LOG"] = "Log";
$lang["CURDIR"] = "Current Directory";
$lang["TARBALL"] = "Tarball";

$lang["PREV"] = "Prev";
$lang["NEXT"] = "Next";
$lang["SHOWALL"] = "Show All";

$lang["BADCMD"] = "Error running this command";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion&nbsp;Projects";
$lang["SERVER"] = "Subversion&nbsp;Server";

$lang["SEARCHLOG"] = "Search log for";
$lang["CLEARLOG"] = "Clear current search";
$lang["MORERESULTS"] = "Find more matches...";
$lang["NORESULTS"] = "There are no logs matching your query";
$lang["NOMORERESULTS"] = "There are no more logs matching your query";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed"; 
$lang["FILESMODIFIED"] = "file(s) modified"; 
$lang["RSSFEED"] = "RSS feed"; 

$lang["LINENO"] = "Line No.";
$lang["BLAMEFOR"] = "Blame information for rev";

$lang["YEARS"] = "years";
$lang["MONTHS"] = "months";
$lang["WEEKS"] = "weeks";
$lang["DAYS"] = "days";
$lang["HOURS"] = "hours";
$lang["MINUTES"] = "minutes";

$lang["GO"] = "Go";

$lang["PATHCOMPARISON"] = "Path Comparison";
$lang["COMPAREPATHS"] = "Compare Paths";
$lang["COMPAREREVS"] = "Compare Revisions";
$lang["PROPCHANGES"] = "Property changes :";
$lang["CONVFROM"] = "This comparison shows the changes necessary to convert path ";
$lang["TO"] = "TO";
$lang["REVCOMP"] = "Reverse comparison";
$lang["COMPPATH"] = "Compare Path:";
$lang["WITHPATH"] = "With Path:";
$lang["FILEDELETED"] = "File deleted";
$lang["FILEADDED"] = "New file";

// The following are defined by some languages to stop unwanted line splitting
// in the template files. 

$lang["NOBR"] = "";
$lang["ENDNOBR"] = "";

// $lang["NOBR"] = "<nobr>";
// $lang["ENDNOBR"] = "</nobr>";
