BODY
{
    COLOR: black;
    FONT-FAMILY: verdana, sans-serif;
    BACKGROUND-COLOR: white
}
HR
{
    BORDER-RIGHT: 0px;
    PADDING-RIGHT: 0px;
    BORDER-TOP: 0px;
    PADDING-LEFT: 0px;
    PADDING-BOTTOM: 0px;
    BORDER-LEFT: 0px;
    PADDING-TOP: 0px;
    BORDER-BOTTOM: 0px;
    HEIGHT: 1px;
    BACKGROUND-COLOR: #808080
}
A
{
    TEXT-DECORATION: none
}
A:hover
{
    TEXT-DECORATION: underline
}
.HdrClmn
{
    BORDER-RIGHT: black 1px solid;
    FONT-WEIGHT: bold;
    COLOR: white;
    BORDER-BOTTOM: black 1px solid;
    BACKGROUND-COLOR: #809cc8
}
.HdrClmnEnd
{
    FONT-WEIGHT: bold;
    COLOR: white;
    BORDER-BOTTOM: black 1px solid;
    BACKGROUND-COLOR: #809cc8
}

.row0
{
   background-color: #F0F0F0;
}

.row1
{
   background-color: #E0E0E0;
}

.CatClmn1
{
    BORDER-RIGHT: black 1px solid;
    BACKGROUND-COLOR: #d0d0ee
}

.CatClmn0
{
    BORDER-RIGHT: black 1px solid;
    BACKGROUND-COLOR: #e0e0ff
}

TD.diffdeleted
{
   font-size: 11px;
   background-color: red;
}

TD.diffchanged
{
   font-size: 11px;
   background-color: yellow;
}

TD.diffadded
{
   font-size: 11px;
   background-color: green;
}

TD.diff
{
   font-size: 11px;
   background-color: #F0F0F0;
}

DIV.newpath
{
   PADDING: 10px 10px 10px 10px;
   BACKGROUND-COLOR: #d0d0ee
}

DIV.difflines
{
}