<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// swedish.inc
//
// Swedish language strings

$lang["LOG"] = "Logg";
$lang["DIFF"] = "Skillnad";

$lang["NOREP"] = "Inget arkiv angivet"; //repository
$lang["NOPATH"] = "S&ouml;kv&auml;gen saknas";
$lang["SUPPLYREP"] = "V&auml;nligen s&auml;tt upp en s&ouml;v&auml;g till arkivet i include/config.inc med \$config->parentPath eller \$config->addRepository<p>Se installationsanvisningen f&ouml;r mer detaljer";

$lang["DIFFREVS"] = "Skillnad mellan rev.";
$lang["AND"] = "och";
$lang["REV"] = "Rev";
$lang["LINE"] = "Rad";
$lang["SHOWENTIREFILE"] = "Visa hela filen";
$lang["SHOWCOMPACT"] = "Visa bara omr&aring;den med skillnader";

$lang["DIFFPREV"] = "Skillnad mot f&ouml;reg&aring;ende";
$lang["BLAME"] = "Ansvarig";

$lang["REVINFO"] = "Revisionsinformation";
$lang["GOYOUNGEST"] = "G&aring; till senaste revision";
$lang["LASTMOD"] = "Senast &auml;ndrad";
$lang["LOGMSG"] = "Loggmeddelande";
$lang["CHANGES"] = "&auml;ndringar";
$lang["SHOWCHANGED"] = "Visa &auml;ndrade filer";
$lang["HIDECHANGED"] = "G&ouml;m &auml;ndrade filer";
$lang["NEWFILES"] = "Nya filer";
$lang["CHANGEDFILES"] = "&Auml;ndrade filer";
$lang["DELETEDFILES"] = "Raderade filer";
$lang["VIEWLOG"] = "Visa&nbsp;Logg";
$lang["PATH"] = "S&ouml;kv&auml;g";
$lang["AUTHOR"] = "F&ouml;rfattare";
$lang["AGE"] = "&Aring;lder";
$lang["LOG"] = "Logg";
$lang["CURDIR"] = "Nuvarande folder";
$lang["TARBALL"] = "Tarball";

$lang["PREV"] = "F&ouml;reg.";
$lang["NEXT"] = "N&auml;sta";
$lang["SHOWALL"] = "Visa alla";

$lang["BADCMD"] = "Fel vid k&ouml;rning av kommande";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion&nbsp;Projekt";
$lang["SERVER"] = "Subversion&nbsp;Server";

$lang["SEARCHLOG"] = "S&ouml;k i logg efter";
$lang["CLEARLOG"] = "Rensa nuvarande s&ouml;kning";
$lang["MORERESULTS"] = "Hitta fler tr&auml;ffar...";
$lang["NORESULTS"] = "Det finns ingen logg som motsvarar din s&ouml;kning";
$lang["NOMORERESULTS"] = "Det finns inga fler loggar i din s&ouml;kning";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed"; 
$lang["FILESMODIFIED"] = "fil(er) &auml;ndrade"; 
$lang["RSSFEED"] = "RSS"; 

$lang["LINENO"] = "Radnr.";
$lang["BLAMEFOR"] = "Ansvariginformation f&ouml;r rev";

$lang["YEARS"] = "&aring;r";
$lang["MONTHS"] = "m&aring;nader";
$lang["WEEKS"] = "veckor";
$lang["DAYS"] = "dagar";
$lang["HOURS"] = "timmar";
$lang["MINUTES"] = "minuter";

$lang["GO"] = "Utf&ouml;r";

$lang["PATHCOMPARISON"] = "S&ouml;kv&auml;gsj&auml;mf&ouml;relse";
$lang["COMPAREPATHS"] = "J&auml;mf&ouml;r s&ouml;kv&auml;gar";
$lang["COMPAREREVS"] = "J&auml;mf&ouml;r revisioner";
$lang["PROPCHANGES"] = "Egenskaps&auml;ndringar :";
$lang["CONVFROM"] = "Denna j&auml;mförelse visar &auml;ndringarna som beh&ouml;vs för att konvertera s&ouml;kv&auml;g "; 
$lang["TO"] = "till";
$lang["REVCOMP"] = "V&auml;xla j&auml;mf&ouml;relse";
$lang["COMPPATH"] = "J&auml;mf&ouml;r s&ouml;kv&auml;g:";
$lang["WITHPATH"] = "Med s&ouml;kv&auml;g:";
$lang["FILEDELETED"] = "Filen raderad";
$lang["FILEADDED"] = "Ny fil";

// The following are defined by some languages to stop unwanted line splitting
// in the template files. 

$lang["NOBR"] = "";
$lang["ENDNOBR"] = "";

// $lang["NOBR"] = "<nobr>";
// $lang["ENDNOBR"] = "</nobr>";


