<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// english.inc
//
// English language strings

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "N&atilde;o foi indicado um reposit&oacute;rio";
$lang["NOPATH"] = "Path Inv&aacute;lida";

$lang["DIFFREVS"] = "Diferen&ccedil;as entre revis&otilde;es";
$lang["AND"] = "e";
$lang["REV"] = "Rev";
$lang["LINE"] = "Linha";
$lang["SHOWENTIREFILE"] = "Mostrar todo o ficheiro";
$lang["SHOWCOMPACT"] = "Mostrar apenas &aacute;reas com diferen&ccedil;as";

$lang["DIFFPREV"] = "Diferen&ccedil;as com a anterior";

$lang["REVINFO"] = "Notas desta revis&atilde;o";
$lang["GOYOUNGEST"] = "Revis&atilde;o mais recente";
$lang["LASTMOD"] = "&Uacute;ltima altera&ccedil;&atilde;o";
$lang["LOGMSG"] = "Mensagem de Log";
$lang["CHANGES"] = "Altera&ccedil;&otilde;es";
$lang["SHOWCHANGED"] = "Mostrar ficheiros alterados";
$lang["HIDECHANGED"] = "Esconder ficheiros alterados";
$lang["NEWFILES"] = "Novos ficheiros";
$lang["CHANGEDFILES"] = "Ficheiros alterados";
$lang["DELETEDFILES"] = "Ficheiros apagados";
$lang["VIEWLOG"] = "Ver&nbsp;Log";
$lang["PATH"] = "Path";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Idade";
$lang["LOG"] = "Log";
$lang["CURDIR"] = "Directoria Currente";

$lang["PREV"] = "Anterior";
$lang["NEXT"] = "Seguinte";
$lang["SHOWALL"] = "Mostrar todos";

$lang["BADCMD"] = "Erro ao correr este comando";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion&nbsp;Projectos";
$lang["SERVER"] = "Subversion&nbsp;Servidor";

$lang["SEARCHLOG"] = "Pesquisar o Search log por";
$lang["CLEARLOG"] = "Limpar pesquisa";
$lang["MORERESULTS"] = "Encontrar mais...";
$lang["NORESULTS"] = "A pesquisa n&atilde;o devolveu nenhum log";
$lang["NOMORERESULTS"] = "N&atilde;o existem mais resultados (logs) para a pesquisa";

$lang["YEARS"] = "anos";
$lang["MONTHS"] = "meses";
$lang["WEEKS"] = "semanas";
$lang["DAYS"] = "dias";
$lang["HOURS"] = "horas";
$lang["MINUTES"] = "minutos";

$lang["GO"] = "Go";
