<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Stephan Stapel, <stephan.stapel@web.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// germany.inc
//
// German language strings

$lang["NOREP"] = "Kein Repository angegeben.";

$lang["DIFFREVS"] = "Vergleich zwischen Revisionen";
$lang["AND"] = "und";
$lang["REV"] = "Revision";
$lang["LINE"] = "Zeile";
$lang["SHOWENTIREFILE"] = "Ganze Datei anzeigen";
$lang["SHOWCOMPACT"] = "Nur ge&auml;nderte Bereiche";

$lang["DIFFPREV"] = "Vergleich mit vorheriger";

$lang["REVINFO"] = "Revisions-Information";
$lang["GOYOUNGEST"] = "Zur aktuellen Revision";                  
$lang["LASTMOD"] = "Letzte &Auml;nderung";
$lang["LOGMSG"] = "Logeintrag";
$lang["CHANGES"] = "Änderungen";                                         
$lang["SHOWCHANGED"] = "Ge&auml;nderte Dateien anzeigen";
$lang["HIDECHANGED"] = "Ge&auml;nderte Dateien verstecken";
$lang["NEWFILES"] = "Neue Dateien";
$lang["CHANGEDFILES"] = "Ge&auml;nderte Dateien";
$lang["DELETEDFILES"] = "Gel&ouml;schte Dateien";
$lang["VIEWLOG"] = "Log&nbsp;anzeigen";
$lang["PATH"] = "Pfad";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Alter";                                                 
$lang["LOG"] = "Log";
$lang["CURDIR"] = "Aktuelles Verzeichnis";                                

$lang["PREV"] = "Zur&uuml;ck";
$lang["NEXT"] = "Weiter";
$lang["SHOWALL"] = "Alles anzeigen";

$lang["BADCMD"] = "Fehler beim Ausf&uuml;hren des Befehls";
   
$lang["PROJECTS"] = "Subversion-Projekte";                       
$lang["SERVER"] = "Subversion Server";                           

$lang["YEARS"] = "Jahre";                                             
$lang["MONTHS"] = "Monate";                                           
$lang["WEEKS"] = "Wochen";                                             
$lang["DAYS"] = "Tage";                                               
$lang["HOURS"] = "Stunden";                                             
$lang["MINUTES"] = "Minuten";   
