
body
{
   font-family: Arial, Helvetica, Geneva, Swiss, SunSans-Regular;
   background-color: white;
   margin: 20px;
   padding: 0px
}

H1
{ 
   color: #99007E;
   font-size: 30px;
   font-weight: normal;
   font-family: Arial, Helvetica, Geneva, Swiss, SunSans-Regular;
   text-decoration: none;
}

HR { color: #99007E; background-color: #99007E  }

.highlight { color: #99007E; font-style: italic;  }

TABLE.bordered, TABLE.outlined, TABLE.blame
{
   border-collapse: collapse;
   border: solid 2px #99007E;
}

.bordered TD, .bordered TH
{
   border: solid 2px #99007E;
}

.outlined TD
{
   padding: 0px 5px 0px 5px;
}

.outlined TH, .blame TH
{
   padding: 5px 5px 5px 5px;
   font-weight: bold;
   border: solid 2px #99007E;
}

.outlined TD, .blame TD
{
   padding: 1px 5px 1px 5px;
   border-right: solid 2px #99007E;
   border-bottom: solid 1px #F0F0F0;
}

TD.diffdeleted
{
   font-size: 11px;
   background-color: red;
}

TD.diffchanged
{
   font-size: 11px;
   background-color: yellow;
}

TD.diffadded
{
   font-size: 11px;
   background-color: green;
}

TD.diff
{
   font-size: 11px;
   background-color: #D0D0D0;
}

TABLE.diff
{
   border-collapse: collapse;
}

DIV.newpath
{
   padding: 5px 5px 5px 5px;
   border: solid 2px #99007E;
}
