<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// japanese-sjis.inc
// Translator: BEPPU Masamichi
//
// Japanese(ShitJIS) language strings

$lang["LOG"] = "ログ";
$lang["DIFF"] = "差分";

$lang["NOREP"] = "リポジトリが指定されていません";
$lang["NOPATH"] = "パスが見付かりません";

$lang["DIFFREVS"] = "リビジョン間の差分";
$lang["AND"] = "と";
$lang["REV"] = "リビジョン";
$lang["LINE"] = "行";
$lang["SHOWENTIREFILE"] = "全て表示";
$lang["SHOWCOMPACT"] = "異なる行の周辺だけ表示";

$lang["DIFFPREV"] = "前のリビジョンとの差分";
$lang["BLAME"] = "詳細表示";

$lang["REVINFO"] = "リビジョン情報";
$lang["GOYOUNGEST"] = "最新のリビジョンへ";
$lang["LASTMOD"] = "最終更新日時";
$lang["LOGMSG"] = "ログメッセージ";
$lang["CHANGES"] = "変更";
$lang["SHOWCHANGED"] = "変更されたファイルの一覧を表示する";
$lang["HIDECHANGED"] = "変更されたファイルの一覧を表示しない";
$lang["NEWFILES"] = "追加ファイル";
$lang["CHANGEDFILES"] = "修正ファイル";
$lang["DELETEDFILES"] = "削除ファイル";
$lang["VIEWLOG"] = "ログを見る";
$lang["PATH"] = "パス";
$lang["AUTHOR"] = "修正者";
$lang["AGE"] = "無修正時間";
$lang["LOG"] = "ログ";
$lang["CURDIR"] = "カレントディレクトリ";

$lang["PREV"] = "前";
$lang["NEXT"] = "次";
$lang["SHOWALL"] = "全て表示";

$lang["BADCMD"] = "コマンド実行中のエラー";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion&nbsp;プロジェクト一覧";
$lang["SERVER"] = "Subversion&nbsp;サーバ";

$lang["SEARCHLOG"] = "ログを検索";
$lang["CLEARLOG"] = "検索条件をクリアする";
$lang["MORERESULTS"] = "検索条件を絞り込む";
$lang["NORESULTS"] = "検索条件にマッチするものはありませんでした";
$lang["NOMORERESULTS"] = "これ以上検索条件にマッチするものはありません";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed"; 
$lang["FILESMODIFIED"] = "ファイルが修正されました"; 
$lang["RSSFEED"] = "RSS feed"; 

$lang["LINENO"] = "行番号";
$lang["BLAMEFOR"] = "詳細表示 対象リビジョン";
                                                                                
$lang["YEARS"] = "年間";
$lang["MONTHS"] = "ヵ月間";
$lang["WEEKS"] = "週間";
$lang["DAYS"] = "日間";
$lang["HOURS"] = "時間";
$lang["MINUTES"] = "分";

$lang["GO"] = "GO";

// The following are defined by some languages to stop unwanted line splitting
// in the template files. 

$lang["NOBR"] = "<nobr>";
$lang["ENDNOBR"] = "</nobr>";
