<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// russian.inc
//
// Russian language strings (win1251)
// 

$lang["LOG"] = "Протокол";
$lang["DIFF"] = "Сравнение";

$lang["NOREP"] = "Репозиторий не задан";
$lang["NOPATH"] = "Путь не найден";

$lang["DIFFREVS"] = "Сравнение ревизий";
$lang["AND"] = "и";
$lang["REV"] = "рев.";
$lang["LINE"] = "Строка";
$lang["SHOWENTIREFILE"] = "Показать целый файл";
$lang["SHOWCOMPACT"] = "Отображать только области с различиями";

$lang["DIFFPREV"] = "Сравнение с предыдущим";
$lang["BLAME"] = "Blame";

$lang["REVINFO"] = "Информация о ревизии";
$lang["GOYOUNGEST"] = "Идти к последней ревизии";
$lang["LASTMOD"] = "Последнее изменение";
$lang["LOGMSG"] = "Регистрационное сообщение";
$lang["CHANGES"] = "Изменения";
$lang["SHOWCHANGED"] = "Показ изменившиеся файлы";
$lang["HIDECHANGED"] = "Скрыть изменившиеся файлы";
$lang["NEWFILES"] = "Новые файлы";
$lang["CHANGEDFILES"] = "Измененные файлы";
$lang["DELETEDFILES"] = "Удаленные файлы";
$lang["VIEWLOG"] = "Смотреть&nbsp;протокол";
$lang["PATH"] = "Путь";
$lang["AUTHOR"] = "Автор";
$lang["AGE"] = "Возраст";
$lang["LOG"] = "Протокол";
$lang["CURDIR"] = "Текущий каталог";

$lang["PREV"] = "Пред.";
$lang["NEXT"] = "След.";
$lang["SHOWALL"] = "Показать всё";

$lang["BADCMD"] = "Ошибка выполнения этой комманды";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion&nbsp;Projects";
$lang["SERVER"] = "Subversion&nbsp;Server";

$lang["SEARCHLOG"] = "Искать log for";
$lang["CLEARLOG"] = "Очистить текущий поиск";
$lang["MORERESULTS"] = "Искать еще совпадения...";
$lang["NORESULTS"] = "There are no logs matching your query";
$lang["NOMORERESULTS"] = "There are no more logs matching your query";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed"; 
$lang["FILESMODIFIED"] = "Фаийл(ы) изменены"; 
$lang["RSSFEED"] = "RSS feed"; 

$lang["LINENO"] = "Строка #.";
$lang["BLAMEFOR"] = "Blame information for rev";

$lang["YEARS"] = "год";
$lang["MONTHS"] = "месяц";
$lang["WEEKS"] = "неделя";
$lang["DAYS"] = "день";
$lang["HOURS"] = "час";
$lang["MINUTES"] = "минута";

$lang["GO"] = "Go";
