<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Erik Le Blanc 
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// french.inc
//
// French language strings

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "Pas de repository";
$lang["NOPATH"] = "Fichier ou r&eacute;pertoire non trouv&eacute;";

$lang["DIFFREVS"] = "Diff&eacute;rences entre les r&eacute;visions";
$lang["AND"] = "et";
$lang["REV"] = "R&eacute;vision";
$lang["LINE"] = "Ligne";
$lang["SHOWENTIREFILE"] = "Afficher tout le fichier";
$lang["SHOWCOMPACT"] = "Afficher seulement les passages avec des diff&eacute;rences";

$lang["DIFFPREV"] = "Diff&eacute;rence avec le pr&eacute;c&eacute;dent";
$lang["BLAME"] = "Responsabilit&eacute;";

$lang["REVINFO"] = "Information sur la R&eacute;vision";
$lang["GOYOUNGEST"] = "Aller &agrave; la R&eacute;vision la plus r&eacute;cente";
$lang["LASTMOD"] = "Derni&egrave;re modification";
$lang["LOGMSG"] = "Message de Log";
$lang["CHANGES"] = "Changements";
$lang["SHOWCHANGED"] = "Montrer les fichiers modifi&eacute;s";
$lang["HIDECHANGED"] = "Cacher les fichiers modifi&eacute;s";
$lang["NEWFILES"] = "Nouveaux fichiers";
$lang["CHANGEDFILES"] = "Fichier(s) modifi&eacute;(s)";
$lang["DELETEDFILES"] = "Fichier(s) effac&eacute;(s)";
$lang["VIEWLOG"] = "Afficher&nbsp;le&nbsp;Log";
$lang["PATH"] = "Chemin";
$lang["AUTHOR"] = "Auteur";
$lang["AGE"] = "Anciennet&eacute;";
$lang["LOG"] = "Log";
$lang["CURDIR"] = "R&eacute;pertoire courant";

$lang["PREV"] = "Pr&eacute;c&eacute;dent";
$lang["NEXT"] = "Suivant";
$lang["SHOWALL"] = "Tout montrer";

$lang["BADCMD"] = "Cette commande a provoqu&eacute; une erreur";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Projets&nbsp;Subversion";
$lang["SERVER"] = "Serveur&nbsp;Subversion";

$lang["SEARCHLOG"] = "Rechercher dans les Logs";
$lang["CLEARLOG"] = "Effacer la recherche courante";
$lang["MORERESULTS"] = "Trouver plus de r&eacute;ponses...";
$lang["NORESULTS"] = "Il n'y a pas de r&eacute;ponse &agrave; votre recherche dans les Logs";
$lang["NOMORERESULTS"] = "Il n'y a pas plus de r&eacute;ponses &agrave; votre recherche";

$lang["RSSFEEDTITLE"] = "Fil RSS de WebSVN"; 
$lang["FILESMODIFIED"] = "fichier(s) modifi&aecute;(s)"; 
$lang["RSSFEED"] = "RSS"; 

$lang["LINENO"] = "Ligne num&eacute;ro";
$lang["BLAMEFOR"] = "Dernier responsable";

$lang["YEARS"] = "ann&eacute;es";
$lang["MONTHS"] = "mois";
$lang["WEEKS"] = "semaines";
$lang["DAYS"] = "jours";
$lang["HOURS"] = "heures";
$lang["MINUTES"] = "minutes";

$lang["GO"] = "Go";

